# This file is part of the History Store (histore).
#
# Copyright (C) 2018-2021 New York University.
#
# The History Store (histore) is released under the Revised BSD License. See
# file LICENSE for full license details.

from histore.archive.base import Archive, PersistentArchive
from histore.archive.manager.persist import PersistentArchiveManager
from histore.document.base import InputDescriptor as Descriptor
